==> apache-skywalking-java-agent-8.8.0-src.tgz: apache-skywalking-java-agent-8.8.0/docs/en/setup/service-agent/java-agent/Plugin-list.md <==
# Skywalking Agent List
- activemq-5.x
- armeria-063-084
- armeria-085
- armeria-086
- armeria-098
- async-http-client-2.x
- avro-1.x
- brpc-java
- canal-1.x
- cassandra-java-driver-3.x
- dbcp-2.x
- druid-1.x
- dubbo
- ehcache-2.x
- elastic-job-2.x
- elasticjob-3.x
- elasticsearch-5.x
- elasticsearch-6.x
- elasticsearch-7.x
- fastjson-1.2.x
- feign-default-http-9.x
- feign-pathvar-9.x
- finagle
- graphql
- grpc-1.x
- gson-2.8.x
- guava-cache
- h2-1.x
- hbase-1.x/2.x
- hikaricp-3.x/4.x
- httpasyncclient-4.x
- httpclient-3.x
- httpclient-4.x
- httpclient-5.x
- hystrix-1.x
- influxdb-2.x
- jackson-2.x
- jdk-http-plugin
- jdk-threading-plugin
- jedis-2.x
- jetty-client-9.0
- jetty-client-9.x
- jetty-server-9.x
- kafka-0.11.x/1.x/2.x
- kotlin-coroutine
- lettuce-5.x
- light4j
- mariadb-2.x
- memcache-2.x
- mongodb-2.x
- mongodb-3.x
- mongodb-4.x
- motan-0.x
- mybatis-3.x
- mysql-5.x
- mysql-6.x
- mysql-8.x
- netty-socketio
- nutz-http-1.x
- nutz-mvc-annotation-1.x
- okhttp-3.x
- okhttp-4.x
- play-2.x
- postgresql-8.x
- pulsar
- quasar
- quartz-scheduler-2.x
- rabbitmq-5.x
- redisson-3.x
- resteasy-server-3.x
- rocketMQ-3.x
- rocketMQ-4.x
- sentinel-1.x
- servicecomb-0.x
- servicecomb-1.x
- sharding-sphere-3.x
- sharding-sphere-4.0.0
- sharding-sphere-4.1.0
- shardingsphere-5.0.0-beta
- sofarpc
- solrj-7.x
- spring-annotation
- spring-async-annotation-5.x
- spring-cloud-feign-1.x
- spring-cloud-feign-2.x
- spring-cloud-gateway-2.0.x
- spring-cloud-gateway-2.1.x
- spring-concurrent-util-4.x
- spring-core-patch
- spring-kafka-1.x
- spring-kafka-2.x
- spring-mvc-annotation
- spring-mvc-annotation-3.x
- spring-mvc-annotation-4.x
- spring-mvc-annotation-5.x
- spring-resttemplate-4.x
- spring-scheduled-annotation
- spring-tx
- spring-webflux-5.x
- spring-webflux-5.x-webclient
- spymemcached-2.x
- struts2-2.x
- thrift
- tomcat-7.x/8.x
- toolkit-counter
- toolkit-gauge
- toolkit-histogram
- toolkit-kafka
- toolkit-log4j
- toolkit-log4j2
- toolkit-logback
- toolkit-opentracing
- toolkit-tag
- toolkit-trace
- toolkit-exception
- undertow-2.x-plugin
- vertx-core-3.x
- xxl-job-2.x
- zookeeper-3.4.x
- mssql-jtds-1.x
- mssql-jdbc
- apache-cxf-3.x
- jsonrpc4j
- spring-cloud-gateway-3.x
- neo4j-4.x
- clickhouse-0.3.x
- kylin-jdbc-2.6.x-3.x-4.x
- okhttp-2.x

==> apache-skywalking-java-agent-8.9.0-src.tgz: apache-skywalking-java-agent-8.9.0/docs/en/setup/service-agent/java-agent/Plugin-list.md <==
# Skywalking Agent List
- activemq-5.x
- armeria-063-084
- armeria-085
- armeria-086
- armeria-098
- async-http-client-2.x
- avro-1.x
- brpc-java
- canal-1.x
- cassandra-java-driver-3.x
- dbcp-2.x
- druid-1.x
- dubbo
- dubbo-2.7.x
- dubbo-3.x
- ehcache-2.x
- elastic-job-2.x
- elasticjob-3.x
- elasticsearch-5.x
- elasticsearch-6.x
- elasticsearch-7.x
- fastjson-1.2.x
- feign-default-http-9.x
- feign-pathvar-9.x
- finagle
- graphql
- grpc-1.x
- gson-2.8.x
- guava-cache
- h2-1.x
- hbase-1.x/2.x
- hikaricp-3.x/4.x
- httpasyncclient-4.x
- httpclient-3.x
- httpclient-4.x
- httpclient-5.x
- hystrix-1.x
- influxdb-2.x
- jackson-2.x
- jdk-http-plugin
- jdk-threading-plugin
- jedis-2.x
- jetty-client-9.0
- jetty-client-9.x
- jetty-server-9.x
- kafka-0.11.x/1.x/2.x
- kotlin-coroutine
- lettuce-5.x
- light4j
- mariadb-2.x
- memcache-2.x
- mongodb-2.x
- mongodb-3.x
- mongodb-4.x
- motan-0.x
- mybatis-3.x
- mysql-5.x
- mysql-6.x
- mysql-8.x
- netty-socketio
- nutz-http-1.x
- nutz-mvc-annotation-1.x
- okhttp-3.x
- okhttp-4.x
- play-2.x
- postgresql-8.x
- pulsar-2.2-2.7
- quasar
- quartz-scheduler-2.x
- rabbitmq-5.x
- redisson-3.x
- resteasy-server-3.x
- rocketMQ-3.x
- rocketMQ-4.x
- sentinel-1.x
- servicecomb-0.x
- servicecomb-1.x
- sharding-sphere-3.x
- sharding-sphere-4.0.0
- sharding-sphere-4.1.0
- sharding-sphere-5.0.0
- sofarpc
- solrj-7.x
- spring-annotation
- spring-async-annotation-5.x
- spring-cloud-feign-1.x
- spring-cloud-feign-2.x
- spring-cloud-gateway-2.0.x
- spring-cloud-gateway-2.1.x
- spring-concurrent-util-4.x
- spring-core-patch
- spring-kafka-1.x
- spring-kafka-2.x
- spring-mvc-annotation
- spring-mvc-annotation-3.x
- spring-mvc-annotation-4.x
- spring-mvc-annotation-5.x
- spring-resttemplate-4.x
- spring-scheduled-annotation
- spring-tx
- spring-webflux-5.x
- spring-webflux-5.x-webclient
- spymemcached-2.x
- struts2-2.x
- thrift
- tomcat-7.x/8.x
- toolkit-counter
- toolkit-gauge
- toolkit-histogram
- toolkit-kafka
- toolkit-log4j
- toolkit-log4j2
- toolkit-logback
- toolkit-opentracing
- toolkit-tag
- toolkit-trace
- toolkit-exception
- undertow-2.x-plugin
- vertx-core-3.x
- xxl-job-2.x
- zookeeper-3.4.x
- mssql-jtds-1.x
- mssql-jdbc
- apache-cxf-3.x
- jsonrpc4j
- spring-cloud-gateway-3.x
- neo4j-4.x
- clickhouse-0.3.x
- kylin-jdbc-2.6.x-3.x-4.x
- okhttp-2.x
- pulsar-2.8.x
